@@ -24,14 +24,16 @@ from .exceptions import (
     RateLimitError,
     BadPassword,
     PleaseWaitFewMinutes,
+    VideoTooLongException,
     UnknownError,
 )
 
 
 def manual_input_code(self, username, choice=None):
     code = None
+    choice_name = {0: 'sms', 1: 'email'}.get(choice)
     while True:
-        code = input("Enter code (6 digits) for %s: " % username).strip()
+        code = input(f"Enter code (6 digits) for {username} ({choice_name}): ").strip()
         if code and code.isdigit():
             break
     return code  # is not int, because it can start from 0
@@ -223,12 +225,14 @@ class PrivateRequest:
                     raise BadPassword(**last_json)
                 elif "Please wait a few minutes before you try again" in message:
                     raise PleaseWaitFewMinutes(e, response=e.response, **last_json)
+                elif "VideoTooLongException" in message:
+                    raise VideoTooLongException(e, response=e.response, **last_json)
                 elif error_type or message:
                     raise UnknownError(**last_json)
                 # TODO: Handle last_json with {'message': 'counter get error', 'status': 'fail'}
                 self.logger.exception(e)
                 self.logger.warning(
-                    "Status 400: %s", message or "Maybe Two-factor auth?"
+                    "Status 400: %s", message or "Empty response message. Maybe enabled Two-factor auth?"
                 )
                 raise ClientBadRequestError(
                     e, response=e.response, **last_json)
