@@ -43,7 +43,7 @@ class Account(BaseModel):
 
 class UserShort(BaseModel):
     pk: int
-    username: str
+    username: Optional[str]
     full_name: Optional[str] = ''
     profile_pic_url: Optional[HttpUrl]
     # is_private: bool
@@ -60,8 +60,8 @@ class Location(BaseModel):
     pk: Optional[int]
     name: str
     address: Optional[str] = ''
-    lng: float
-    lat: float
+    lng: Optional[float]
+    lat: Optional[float]
     external_id: Optional[int]
     external_id_source: Optional[str]
     # address_json: Optional[dict] = {}
@@ -186,3 +186,10 @@ class DirectThread(BaseModel):
     assigned_admin_id: int
     shh_mode_enabled: bool
     last_seen_at: dict
+
+
+class Hashtag(BaseModel):
+    id: int
+    name: str
+    media_count: Optional[int]
+    profile_pic_url: Optional[HttpUrl]
